@@ -89,7 +89,7 @@ class EnginesAPI(object):
         a_dict = {item.name: item.id for item in all_engine_servers}
         return a_dict.get(engine_name)
 
-    def register_engine(self, name, uri, min_loc, max_loc, is_blocked, api_version="1.0"):
+    def register_engine(self, name, uri, min_loc, max_loc, is_blocked, max_scans, api_version="1.0"):
         """
         POST  /sast/engineServers  Registers an Engine Server
         Args:
@@ -98,6 +98,7 @@ class EnginesAPI(object):
             min_loc (int): Specifies the minimum number of lines of code to scan
             max_loc (int): Specifies the maximum number of lines of code to scan
             is_blocked (boolean): Specifies whether or not the engine will be able to receive scan requests
+            max_scans (int):
             api_version (str, optional):
 
         Returns:
@@ -113,7 +114,8 @@ class EnginesAPI(object):
             uri=uri,
             min_loc=min_loc,
             max_loc=max_loc,
-            is_blocked=is_blocked
+            is_blocked=is_blocked,
+            max_scans=max_scans
         ).get_post_data()
 
         engine_servers_url = config.get("base_url") + "/cxrestapi/sast/engineServers"
