@@ -8,7 +8,7 @@ class CxCreateScan(object):
     the data when create scan
     """
 
-    def __init__(self, project_id, is_incremental, is_public, force_scan, comment):
+    def __init__(self, project_id, is_incremental, is_public, force_scan, comment, custom_fields=None):
         """
 
         Args:
@@ -17,12 +17,14 @@ class CxCreateScan(object):
             is_public (boolean):
             force_scan (boolean):
             comment (str):
+            custom_fields (dict, optional):
         """
         self.project_id = project_id
         self.is_incremental = is_incremental
         self.is_public = is_public
         self.force_scan = force_scan
         self.comment = comment
+        self.custom_fields = custom_fields
 
     def get_post_data(self):
         return json.dumps(
@@ -31,11 +33,13 @@ class CxCreateScan(object):
                 "isIncremental": self.is_incremental,
                 "isPublic": self.is_public,
                 "forceScan": self.force_scan,
-                "comment": self.comment
+                "comment": self.comment,
+                "customFields": self.custom_fields
             }
         )
 
     def __str__(self):
-        return "CxCreateScan(project_id={}, is_incremental={}, is_public={}, force_scan={}, comment={})".format(
-            self.project_id, self.is_incremental, self.is_public, self.force_scan, self.comment
+        return """CxCreateScan(project_id={}, is_incremental={}, is_public={}, force_scan={}, comment={}, 
+        custom_fields={})""".format(
+            self.project_id, self.is_incremental, self.is_public, self.force_scan, self.comment, self.custom_fields
         )
